import axios from "axios";

function getCurrentTimestamp() {
    return new Date().getTime();
}

const api = 'http://nbxt.oa.x-lf.cn'

/**
 * 根据项目id获取项目信息
 * @param id 项目id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
const projectGetById = (id, token) => {
    return axios({
        url: api + "/project/get/id?id=" + id,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }
    })
}


/**
 * 获取项目信息
 * @param projectId 项目id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */

export const getproject = (projectId, token) => {
    return axios({
        url: api +"/project/get?projectId=" + projectId,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()

        }


    })
}



/**
 * 获取我管理页面的项目列表(接口有问题)
 * 
 * @param pageSize 页面大小
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getManageList = (params ,token ,) => {

    const {pageSize ,is ,page} = params;
    return axios({
        url:  `${api}/project/child/get?is=${is}&pageSize=${pageSize}&page=${page}` ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
            

        }


    })
}

// 我管理的所有接口



/**
 * 获取我管理的页面的项目列表
 * 
 * @param projectId 项目id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getManageProjectList = (token) => {
    return axios({
        url: api +'/project/child/get' ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }

    })

}






/**
 * 获取我管理的页面的子系统项目列表
 * @param projectId 项目id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getProjectSysList = (projectId,token) => {
    return axios({
        url: api +"/module/get?projectId=" + projectId ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }


    })
}
/**
 * 获取我管理的页面的子模块项目列表(接口没数据)
 * @param sysId 子系统id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getProjectModList = (sysId,token) => {
    return axios({
        url: api +"/module/get/min?sysId=" + sysId ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }


    })
}
/**
 * 获取我管理的页面的子模块详细信息
 * @param id 子模块id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const getProjectModDetail = (id,token) => {
    return axios({
        url: api +"/project/module/id?id=" + id ,
        method: "get",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }


    })
}
//功能接口


//删除项目

/**
 * 选择项目删除
 * @param id 项目id
 * @param token 访问令牌
 * @returns {Promise<AxiosResponse<any>> | *}
 */
export const deleteProject = (id,token) => {
    return axios({
        url: api +"/project/delete?id=" + id ,
        method: "delete",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        }


    })
}
/**
 * 修改项目信息
 * @param {Object} body 包含项目更新信息的对象
 * @param {number} id 项目ID
 * @param {string} token 访问令牌
 * @returns {Promise<AxiosResponse<any>>}
 */
export const editProject = (body ,id,token) => {
    return axios({
        url: api +"/project/edit?id=" + id ,
        method: "put",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        },
        data:body


    })
}

/**
 * 
 * 新增子模块
 * @param {Object} body 包含项目更新信息的对象
 * @param {string} token 访问令牌
 * @returns {Promise<AxiosResponse<any>>}
 * 
 */
export const addModule = (body,token) => {
    return axios({
        url: api +"/project/module/add" ,
        method: "post",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        },
        data:body


    })
}
/**
 * 
 * 删除子模块
 * @param {number} id 子模块ID
 * @param {string} token 访问令牌
 * @returns {Promise<AxiosResponse<any>>}
 * 
 */
export const deleteModule = (id,token) => {
    return axios({
        url: api +"/project/module/delete?id=" +id ,
        method: "delete",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        },
        


    })
}
/**
 * 
 * 修改子模块
 * @param {number} id 子模块ID
 * @param {Object} body 包含子模块更新信息的对象
 * @param {string} token 访问令牌
 * @returns {Promise<AxiosResponse<any>>}
 * 
 */
export const editModule = ( body,id,token) => {
    return axios({
        url: api +"/project/module/edit?id=" +id ,
        method: "put",
        headers: {
            'Authorization': 'Bearer ' + token,
            'Timestamp': getCurrentTimestamp()
        },
        data:body
        


    })
}










